@@ -1,8 +1,10 @@
 #Plots the polygons in pal imported by get.paldata according
 #to the arcs in arc (value returned by get.arcdata)
-plotpal<-function(arc,pal, new=TRUE, ...)
+plotpal<-function(arc,pal, new=TRUE, index=NULL,...)
 {
 
+	if(is.null(index))
+		index<-1:length(pal[[2]])
 	#We only need the lists of arcs
 	arc<-arc[[2]]
 	pal<-pal[[2]]
@@ -10,15 +12,13 @@ plotpal<-function(arc,pal, new=TRUE, ...)
 	larc<-length(arc)
 	arcs<-vector(mode="logical", length=larc)
 
-	lpal<-length(pal)
 
-
-	for(i in 1:lpal)
+	for(p in index)
 	{
-		l<-length(pal[[i]][[1]])
-		for(j in 1:l)
+		l<-length(pal[[p]][[1]])
+		for(a in 1:l)
 		{
-			arcs[abs(pal[[i]][[1]][j])]<-TRUE	
+			arcs[abs(pal[[p]][[1]][a])]<-TRUE	
 		}
 	}
 
